#
# spec file for package powerline-go
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           powerline-go
Version:        1.25
Release:        1.1
Summary:        A Powerline like prompt for Bash, ZSH and Fish
License:        GPL-3.0-or-later
Group:          System/Console
URL:            https://github.com/justjanne/powerline-go
Source0:        https://github.com/justjanne/powerline-go/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.24
%{go_nostrip}

%description
A Powerline like prompt for Bash, ZSH and Fish. Based on Powerline-Shell by @banga. Ported to golang by @justjanne.

%prep
%autosetup -a1 -n %{name}-%{version}

%build
go build --mod=vendor -buildmode=pie

%install
install -D -m 755 %{name} %{buildroot}%{_bindir}/%{name}

%check
go test -v

%files
%license LICENSE.md
%doc README.md
%{_bindir}/%{name}

%changelog
* Sun May 18 2025 Dirk Müller <dmueller@suse.com>
- update to 1.25:
  * feat: virtualenv improvements
  * Fix for empty string value from pyvenv.cfg parsing
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.24:
  * Add exit codes for an IBM Z OS, named 'zos'
  * Goreleaser pipeline to build more archs and make release
    workflow more reliable
  * AWS module try to use AWS_VAULT when AWS_PROFILE is not set
  * Use altermative prompt from python venv
  * Background tasks should use --no-optional-locks to prevent
    issues with other tools running at the same time.
  * Add "git branch" symbol to gitlite module (if git mode is not
    "compact")
* Mon Mar 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.22.1:
  * Changed bold foreground back to default, made it into an
    option set by themes
  * #298 Added a new "compact" Git mode, with less width than
    "fancy", and a bit more information than "simple" (@jacobo-
    diaz)
  * #308 add low precision duration setting (@pridkett)
  * #310 Restyle nix-shell segment (@jonascarpay)
  * #321 Add support to show current date and time (@flybyray)
  * #330 Added segment to display current node version (@caleb-
    artifact)
  * #331 Increased the performance of GCP segment (@caleb-
    artifact)
  * #333 Add more exit code strings (@scop)
  * #336 Add vi-mode segment (@blackheaven)
  * #338 Add Openshift cluster context shortening (@stas2k)
  * #339 Allow node indicator to be overridden (@mjgiarlo)
  * #340 Add RVM segment for Rubyists who use RVM (@mjgiarlo)
  * #349 make foreground color bold (@buckley310)
  * #351 Add support for DOCKER_CONTEXT environment variable
  * #352 direnv support (@scop)
  * #289 Avoid a git rev-list if stash stats are disabled (@scop)
  * #292 Fix prompt for Fish Shell (@cfinnberg)
  * #294 fallback to $PWD if os.Getwd returns error (@vgropp)
  * #296 git ignores global config gitexcludes/.git/config/ignore
  * #301 Path should be escaped in plain mode (@dswij)
  * #312 Improve shell detection (@scop)
  * #314 only warn about shellVarName not existing if it's been
    set (@kchiem)
  * #317 Try to escape virtualenv on Git Bash for Windows
  * #319 Replace wc with fish builtin count (@kidonng)
  * #341 Do not render node package segment if no version found
* Thu Jul 15 2021 pandom79@gmail.com
- Update to version 1.21.0:
  * Fix typod flag name to re-enable prompt shrinking when `-max-width` is specified
  * added signal numbers for DragonFly BSD
  * Improve README for -colorize-hostname
  * Corrects whitespace in README.md
  * Fixes return value in bzr and fossil segments and adds modules bzr and fossil to README.md
  * fixed terraform refactor
  * use happy path for better code readability
  * Use goenv's colors for vgo too
  * Added Fossil segment
  * Added Bazaar segment
* Tue Jun 22 2021 Domenico Panella <pandom79@gmail.com>
- Several bugfixes and improvements thanks to the help from many contributors :)
